<TS language="ml" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>വിലാസം അല്ലെങ്കിൽ ലേബൽ എഡിറ്റുചെയ്യാൻ വലത് ക്ലിക്കുചെയ്യുക</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>ഒരു പുതിയ വിലാസം സൃഷ്ടിക്കുക</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;പുതിയത്</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം സിസ്റ്റം ക്ലിപ്പ്ബോർഡിലേക്ക് പകർത്തുക</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;പകർത്തുക</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>അ&amp;ടയ്ക്കുക</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>പട്ടികയിൽ നിന്ന് നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>തിരയുന്നതിന് വിലാസമോ ലേബലോ നൽകുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>നാണയങ്ങൾ അയയ്ക്കാനുള്ള വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>നാണയങ്ങൾ സ്വീകരിക്കാൻ വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>തി&amp;രഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>വിലാസങ്ങൾ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>സ്വീകരിക്കുന്ന വിലാസങ്ങൾ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>പേയ്മെന്റുകൾ അയയ്ക്കുന്നതിനുള്ള നിങ്ങളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങളാണ് ഇവ. നാണയങ്ങൾ അയയ്ക്കുന്നതിനുമുമ്പ് എല്ലായ്പ്പോഴും തുകയും സ്വീകരിക്കുന്ന വിലാസവും പരിശോധിക്കുക.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation>ഇവയാണ് പണം  സ്വീകരിയ്ക്കുന്നതിനായുള്ള താങ്കളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങൾ. പുതിയ വിലാസങ്ങൾ കൂട്ടിച്ചേർക്കുന്നതിനായി ' പുതിയ വിലാസം സൃഷ്ടിയ്ക്കുക ' എന്ന ബട്ടൺ അമർത്തുക.
'ലെഗസി' തരത്തിന്റെ വിലാസങ്ങളിൽ മാത്രമേ സൈൻ ചെയ്യാൻ കഴിയൂ.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;വിലാസം പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>പകർത്തുക &amp;ലേബൽ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ചിട്ടപ്പെടുത്തുക</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>കയറ്റുമതി വിലാസ ലിസ്റ്റ്</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>%1 ലേക്ക് വിലാസ ലിസ്റ്റ് സംരക്ഷിക്കാൻ ശ്രമിക്കുന്നതിൽ ഒരു പിശകുണ്ടായിരുന്നു. വീണ്ടും ശ്രമിക്കുക.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>രഹസ്യപദപ്രയോഗ സംഭാഷണം</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>രഹസ്യപദപ്രയോഗം നൽകുക</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം ആവർത്തിക്കുക</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>രഹസ്യപദം  കാണിക്കുക </translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>നിങ്ങളുടെ വാലറ്റ് അൺലോക്കുചെയ്യാൻ ഈ പ്രവർത്തനത്തിന് നിങ്ങളുടെ വാലറ്റ് രഹസ്യപദപ്രയോഗം ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>വാലറ്റ് അൺലോക്ക് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ഈ പ്രവർത്തനത്തിന് വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുന്നതിന് നിങ്ങളുടെ വാലറ്റ് പാസ്ഫ്രെയ്സ് ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>പാസ്ഫ്രെയ്സ് മാറ്റുക</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>വാലറ്റ് എൻക്രിപ്ഷൻ സ്ഥിരീകരിക്കുക</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>മുന്നറിയിപ്പ്: നിങ്ങളുടെ വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്ത് പാസ്ഫ്രെയ്സ് നഷ്ടപ്പെടുകയാണെങ്കിൽ, നിങ്ങളുടെ എല്ലാ ബിറ്റ്കൊയിനുകളും നഷ്ടപ്പെടും!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>നിങ്ങളുടെ വാലറ്റ് എൻ‌ക്രിപ്റ്റ് ചെയ്യാൻ ആഗ്രഹിക്കുന്നുവെന്ന് ഉറപ്പാണോ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>വാലറ്റ് എന്ക്രിപ്റ് ചെയ്തു കഴിഞ്ഞു .</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>വാലറ്റിൽ പുതിയ പാസ്ഫ്രെയ്സ് നൽകുക. &lt;br/&gt; &lt;b&gt; പത്തോ അതിലധികമോ റാൻഡം പ്രതീകങ്ങൾ &lt;/b&gt; അല്ലെങ്കിൽ  &lt;b&gt;എട്ട് അല്ലെങ്കിൽ അതിൽ കൂടുതൽ വാക്കുകൾ &lt;/b&gt; ഒരു പാസ്ഫ്രെയ്സ് ഉപയോഗിക്കുക.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>വാലെറ്റിന്റെ പഴയ രഹസ്യപദവും പുതിയ രഹസ്യപദവും നൽകുക.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>നിങ്ങളുടെ വാലറ്റ് എൻ‌ക്രിപ്റ്റ് ചെയ്യുന്നതിലൂടെ നിങ്ങളുടെ കമ്പ്യൂട്ടറിനെ ബാധിക്കുന്ന ക്ഷുദ്രവെയർ‌ മോഷ്ടിക്കുന്നതിൽ‌ നിന്നും നിങ്ങളുടെ ബിറ്റ്കോയിനുകളെ പൂർണ്ണമായി സംരക്ഷിക്കാൻ‌ കഴിയില്ല.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>വാലറ്റ് എന്ക്രിപ്റ് ചെയ്യാൻ പോകുന്നു .</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>വാലറ്റ് എന്ക്രിപ്റ് ചെയ്യാൻ പോകുന്നു .</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>വാലറ്റ് എന്ക്രിപ്റ് ചെയ്തു കഴിഞ്ഞു .</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>പ്രധാനം: നിങ്ങളുടെ വാലറ്റ് ഫയലിൽ മുമ്പ് നിർമ്മിച്ച ഏതെങ്കിലും ബാക്കപ്പുകൾ പുതുതായി ജനറേറ്റുചെയ്ത, എൻ‌ക്രിപ്റ്റ് ചെയ്ത വാലറ്റ് ഫയൽ ഉപയോഗിച്ച് മാറ്റിസ്ഥാപിക്കണം. സുരക്ഷാ കാരണങ്ങളാൽ, നിങ്ങൾ പുതിയ, എൻ‌ക്രിപ്റ്റ് ചെയ്ത വാലറ്റ് ഉപയോഗിക്കാൻ ആരംഭിക്കുമ്പോൾ തന്നെ എൻ‌ക്രിപ്റ്റ് ചെയ്യാത്ത വാലറ്റ് ഫയലിന്റെ മുമ്പത്തെ ബാക്കപ്പുകൾ ഉപയോഗശൂന്യമാകും.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>വാലറ്റ് എന്ക്രിപ്റ് പരാജയപെട്ടു  .</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>ആന്തരിക പിശക് കാരണം വാലറ്റ് എൻ‌ക്രിപ്ഷൻ പരാജയപ്പെട്ടു. നിങ്ങളുടെ വാലറ്റ് എൻ‌ക്രിപ്റ്റ് ചെയ്തിട്ടില്ല.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>വിതരണം ചെയ്ത പാസ്‌ഫ്രെയ്‌സുകൾ പൊരുത്തപ്പെടുന്നില്ല.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>വാലറ്റ് അൺലോക്ക് പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>വാലറ്റ് ഡീക്രിപ്ഷനായി നൽകിയ പാസ്‌ഫ്രേസ് തെറ്റാണ്.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>വാലറ്റ് ഡീക്രിപ്ഷൻ പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>വാലറ്റ് പാസ്‌ഫ്രെയ്‌സ് വിജയകരമായി മാറ്റി.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>മുന്നറിയിപ്പ്: ക്യാപ്‌സ് ലോക്ക് കീ ഓണാണ്!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP / നെറ്റ്മാസ്ക്</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>വരെ നിരോധിച്ചു</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>സൈനും സന്ദേശവും ...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>നെറ്റ്‌വർക്കുമായി സമന്വയിപ്പിക്കുന്നു ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;അവലോകനം</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>വാലറ്റിന്റെ പൊതുവായ അവലോകനം കാണിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ഇടപാടുകൾ </translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>ഇടപാടുകളുടെ ചരിത്രം പരിശോധിയ്ക്കുക</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>പുറത്ത്</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>അപ്ലിക്കേഷൻ ഉപേക്ഷിക്കുക</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp; ഏകദേശം%1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1 നെക്കുറിച്ചുള്ള വിവരങ്ങൾ കാണിക്കുക</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>ഏകദേശം&amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Qt സംബന്ധിച്ച വിവരങ്ങൾ കാണിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ഓപ്ഷനുകൾ ...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>%1 നായുള്ള കോൺഫിഗറേഷൻ ഓപ്ഷനുകൾ പരിഷ്‌ക്കരിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;വാലറ്റ് എൻ‌ക്രിപ്റ്റ് ചെയ്യുക ...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;ബാക്കപ്പ് വാലറ്റ് ...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;പാസ്ഫ്രെയ്സ് മാറ്റുക</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>തുറക്കുക &amp;URI ...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>വാലറ്റ്  സൃഷ്ടിക്കുക :</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>ഒരു പുതിയ വാലറ്റ് സൃഷ്ടിക്കുക</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>വാലറ്റ്:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>നെറ്റ്‌വർക്ക് പ്രവർത്തനം പ്രവർത്തനരഹിതമാക്കാൻ ക്ലിക്കുചെയ്യുക.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>നെറ്റ്‌വർക്ക് പ്രവർത്തനം പ്രവർത്തനരഹിതമാക്കി.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>നെറ്റ്‌വർക്ക് പ്രവർത്തനം വീണ്ടും പ്രവർത്തനക്ഷമമാക്കാൻ ക്ലിക്കുചെയ്യുക.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>തലക്കെട്ടുകൾ സമന്വയിപ്പിക്കുന്നു (%1%) ...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>ഡിസ്കിലെ ബ്ലോക്കുകൾ വീണ്ടും സമന്വയിപ്പിക്കുന്നു ...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>പ്രോക്സി ആണ്&lt;b&gt;പ്രവർത്തനക്ഷമമാക്കി&lt;/b&gt;:%1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>ഒരു ബിറ്റ്കോയിൻ വിലാസത്തിലേക്ക് നാണയങ്ങൾ അയയ്ക്കുക</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>മറ്റൊരു സ്ഥലത്തേക്ക് ബാക്കപ്പ് വാലറ്റ്</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>വാലറ്റ് എൻ‌ക്രിപ്ഷനായി ഉപയോഗിക്കുന്ന പാസ്‌ഫ്രെയ്‌സ് മാറ്റുക</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verify സന്ദേശം  ...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;അയയ്‌ക്കുക</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;സ്വീകരിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;കാണിക്കുക/ മറയ്ക്കുക</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>പ്രധാന വിൻ‌ഡോ കാണിക്കുക അല്ലെങ്കിൽ‌ മറയ്‌ക്കുക</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>നിങ്ങളുടെ വാലറ്റിന്റെ സ്വകാര്യ കീകൾ എൻ‌ക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>നിങ്ങളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങൾ സ്വന്തമാണെന്ന് തെളിയിക്കാൻ സന്ദേശങ്ങൾ ഒപ്പിടുക</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>നിർദ്ദിഷ്ട ബിറ്റ്കോയിൻ വിലാസങ്ങളിൽ സന്ദേശങ്ങൾ ഒപ്പിട്ടിട്ടുണ്ടെന്ന് ഉറപ്പാക്കാൻ സ്ഥിരീകരിക്കുക</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp; ഫയൽ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;ക്രമീകരണങ്ങൾ</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;സഹായം</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>ടാബുകളുടെ ടൂൾബാർ</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>പേയ്‌മെന്റുകൾ അഭ്യർത്ഥിക്കുക (QR കോഡുകളും ബിറ്റ്കോയിനും സൃഷ്ടിക്കുന്നു: URI- കൾ)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>ഉപയോഗിച്ച അയച്ച വിലാസങ്ങളുടെയും ലേബലുകളുടെയും പട്ടിക കാണിക്കുക</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>ഉപയോഗിച്ച സ്വീകരിക്കുന്ന വിലാസങ്ങളുടെയും ലേബലുകളുടെയും പട്ടിക കാണിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;കമാൻഡ്-ലൈൻ ഓപ്ഷനുകൾ</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>ഡിസ്കിലെ ബ്ലോക്കുകൾ ഇൻഡെക്സ് ചെയ്യുന്നു ...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>ഡിസ്കിൽ ബ്ലോക്കുകൾ പ്രോസസ്സ് ചെയ്യുന്നു ...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>ഇടപാട് ചരിത്രത്തിന്റെ %n ബ്ലോക്കുകൾ പ്രോസസ്സ് ചെയ്തു.</numerusform><numerusform>ഇടപാട് ചരിത്രത്തിന്റെ %n ബ്ലോക്കുകൾ പ്രോസസ്സ് ചെയ്തു.</numerusform></translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>അവസാനം ലഭിച്ച ബ്ലോക്ക് %1 മുമ്പ് സൃഷ്ടിച്ചു.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>ഇതിനുശേഷമുള്ള ഇടപാടുകൾ ഇതുവരെ ദൃശ്യമാകില്ല.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>പിശക് </translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>മുന്നറിയിപ്പ് </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>വിവരം </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>കാലികമാണ്</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file...</source>
        <translation>&amp;ഫയലിൽ നിന്ന് PSBT ലോഡുചെയ്യുക ...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation>ഭാഗികമായി ഒപ്പിട്ട ബിറ്റ്കോയിൻ ഇടപാട് ലോഡുചെയ്യുക</translation>
    </message>
    <message>
        <source>Load PSBT from clipboard...</source>
        <translation>ക്ലിപ്പ്ബോർഡിൽ നിന്ന് PSBT ലോഡുചെയ്യുക ...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation>ക്ലിപ്പ്ബോർഡിൽ നിന്ന് ഭാഗികമായി ഒപ്പിട്ട ബിറ്റ്കോയിൻ ഇടപാട് ലോഡുചെയ്യുക</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>നോഡ് വിൻഡോ</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>നോഡ് ഡീബഗ്ഗിംഗും ഡയഗ്നോസ്റ്റിക് കൺസോളും തുറക്കുക</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;വിലാസങ്ങൾ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;വിലാസങ്ങൾ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation>ഒരു ബിറ്റ്കോയിൻ തുറക്കുക: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>വാലറ്റ് തുറക്കുക </translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>ഒരു വാലറ്റ് തുറക്കുക </translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>വാലറ്റ്  പൂട്ടുക  </translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>വാലറ്റ് പൂട്ടുക </translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>എല്ലാ വാലറ്റുകളും അടയ്‌ക്കുക ...</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>എല്ലാ വാലറ്റുകളും അടയ്‌ക്കുക ...</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>സാധ്യമായ ബിറ്റ്കോയിൻ കമാൻഡ്-ലൈൻ ഓപ്ഷനുകളുള്ള ഒരു ലിസ്റ്റ് ലഭിക്കുന്നതിന് %1 സഹായ സന്ദേശം കാണിക്കുക</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation>&amp;മാസ്ക് മൂല്യങ്ങൾ</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation>അവലോകന ടാബിൽ മൂല്യങ്ങൾ മാസ്ക് ചെയ്യുക</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>സ്ഥിരം ആയ വാലറ്റ്</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation>വാലറ്റ് ഒന്നും ലഭ്യം അല്ല </translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;ജാലകം </translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>ചെറുതാക്കുക </translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>വലുതാക്കുക </translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>മുഖ്യ ജാലകം </translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 ക്ലയന്റ്</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>സുഹൃത്തുക്കളും ആയി കണക്ട് ചെയ്യുന്നു ...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>കണ്ടുപിടിക്കുന്നു ...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>തെറ്റ് : %1 </translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>മുന്നറിയിപ്പ് : %1 </translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>തീയതി: %1 
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>തുക : %1 
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>വാലറ്റ്: %1 
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>തരങ്ങൾ: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>കുറിപ്പ് : %1 
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>മേൽവിലാസം : %1 
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>അയച്ച ഇടപാടുകൾ </translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>വരവ്വ് വെച്ച ഇടപാടുകൾ </translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>എച്ച്ഡി കീ ജനറേഷൻ&lt;b&gt;പ്രവർത്തനക്ഷമമാക്കി&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>എച്ച്ഡി കീ ജനറേഷൻ&lt;b&gt;പ്രവർത്തനരഹിതമാക്കി&lt;/b&gt;`</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>സ്വകാര്യ കീ&lt;b&gt;പ്രവർത്തനരഹിതമാക്കി&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Wallet &lt;b&gt;എൻ‌ക്രിപ്റ്റ് ചെയ്തു&lt;/b&gt;നിലവിൽ&lt;b&gt;അൺലോക്കുചെയ്‌തു&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Wallet &lt;b&gt;എൻ‌ക്രിപ്റ്റ് ചെയ്തു&lt;/b&gt;നിലവിൽ&lt;b&gt;പൂട്ടി&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation>യഥാർത്ഥ സന്ദേശം:</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>മാരകമായ ഒരു പിശക് സംഭവിച്ചു. %1 ന് മേലിൽ സുരക്ഷിതമായി തുടരാനാകില്ല, ഒപ്പം ഉപേക്ഷിക്കുകയും ചെയ്യും.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>കോയിൻ തിരഞ്ഞെടുക്കൽ </translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>നിര്‍ദ്ധിഷ്‌ടസംഖ്യ / അളവ് :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ബൈറ്റ്സ്:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>തുക:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ഫീസ്‌ / പ്രതിഫലം :</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>ഡസ്ട്:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ഫീസ് കഴിഞ്ഞ്:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>മാറ്റം:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>എല്ലാം തിരഞ്ഞു (എടുക്കുക /എടുക്കാതിരിക്കുക)</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>ട്രീ മോഡ്</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>പട്ടിക </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>തുക </translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>അടയാളത്തോടുകൂടി ലഭിച്ചു </translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>മേൽവിലാസത്തോടുകൂടി ലഭിച്ചു </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>തീയതി </translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>സ്ഥിതീകരണങ്ങൾ </translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>സ്ഥിതീകരിച്ചു</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>വിലാസം പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>പകർത്തുക  ലേബൽ</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>തുക പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>ഇടപാട് ഐഡി പകർത്തുക</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>ചെലവഴിക്കാത്തത് പൂട്ടുക</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>അൺസ്പെന്റുകൾ അൺലോക്ക് ചെയ്യുക </translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>നിര്‍ദ്ധിഷ്‌ടസംഖ്യ / അളവ് പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>പകർത്തു ഫീസ്</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>ശേഷമുള്ള ഫീ പകർത്തു</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>ബൈറ്റ്സ് പകർത്തു</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>ഡസ്ട് പകർത്തു</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>ചേഞ്ച് പകർത്തു</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 ലോക്ക് ആക്കിയിരിക്കുന്നു)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>അതെ / ശരി</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ഇല്ല</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>ഏതെങ്കിലും സ്വീകർത്താവിന് നിലവിലെ ഡസ്ട് പരിധിയേക്കാൾ ചെറിയ തുക ലഭിക്കുകയാണെങ്കിൽ ഈ ലേബൽ ചുവപ്പായി മാറുന്നു.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>ഒരു ഇൻപുട്ടിന് +/-%1 സതോഷി(കൾ) വ്യത്യാസം ഉണ്ടാകാം.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>%1 (%2) ൽ നിന്ന് മാറ്റുക</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(മാറ്റം)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <translation>വാലറ്റ് രൂപീകരിക്കുന്നു &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation>വാലറ്റ് രൂപീകരണം പരാജയപ്പെട്ടു </translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation>വാലറ്റ് രൂപീകരണത്തിലെ മുന്നറിയിപ്പ് </translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>വാലറ്റ് / പണസഞ്ചി സൃഷ്ടിക്കുക :</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>വാലറ്റ് പേര്</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation>എൻ‌ക്രിപ്റ്റ് വാലറ്റ്</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>എൻ‌ക്രിപ്റ്റ് വാലറ്റ്</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation> സ്വകാര്യ കീകൾ പ്രവർത്തനരഹിതമാക്കുക </translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation>ശൂന്യമായ വാലറ്റ് നിർമ്മിക്കുക</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>സൃഷ്ടിക്കുക</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>വിലാസം എഡിറ്റുചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;ലേബൽ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp; വിലാസം</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>പുതിയ അയയ്‌ക്കുന്ന വിലാസം</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>സ്വീകരിക്കുന്ന വിലാസം എഡിറ്റുചെയ്യുക</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>അയയ്‌ക്കുന്ന വിലാസം എഡിറ്റുചെയ്യുക</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>വാലറ്റ് അൺലോക്കുചെയ്യാനായില്ല.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>പുതിയ കീ ജനറേഷൻ പരാജയപ്പെട്ടു</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>ഒരു പുതിയ ഡാറ്റ ഡയറക്ടറി സൃഷ്ടിക്കും.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>നാമധേയം / പേര് </translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>പാത്ത് ഇതിനകം നിലവിലുണ്ട്, അത് ഒരു ഡയറക്ടറിയല്ല.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>ഡാറ്റ ഡയറക്ടറി ഇവിടെ സൃഷ്ടിക്കാൻ കഴിയില്ല.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>പതിപ്പ്</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>കമാൻഡ്-ലൈൻ ഓപ്ഷനുകൾ</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>സ്വാഗതം</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>ബിറ്റ്കോയിൻ</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>പിശക് </translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>ഫോം </translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>അവശേഷിക്കുന്ന ബ്ലോക്കുകൾ </translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>അജ്ഞാതമായ </translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>അവസാന ബ്ലോക്കിന്റെ സമയം </translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>പുരോഗതി</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>കണക്കായ്ക്കിക്കൊണ്ടിരിക്കുന്നു</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>സ്ഥിരം ആയ വാലറ്റ്</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;ജാലകം </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>പിശക് </translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>ഫോം </translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>ലഭ്യമായ</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>വിനിയോഗിക്കാവുന്നത് / ചെലവാക്കാവുന്നത് </translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>സമീപ കാല ഇടപാടുകൾ</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>URI handling</source>
        <translation>യു‌ആർ‌ഐ കൈകാര്യം ചെയ്യൽ</translation>
    </message>
    <message>
        <source>'bitcoin://' is not a valid URI. Use 'bitcoin:' instead.</source>
        <translation>'bitcoin://' എന്നത് ശരിയായ ഒരു URI അല്ല .പകരം 'bitcoin:' ഉപയോഗിക്കൂ </translation>
    </message>
    <message>
        <source>Cannot process payment request because BIP70 is not supported.</source>
        <translation>BIP70 പിന്തുണയ്‌ക്കാത്തതിനാൽ പേയ്‌മെന്റ് അഭ്യർത്ഥന പ്രോസസ്സ് ചെയ്യാൻ കഴിയില്ല.</translation>
    </message>
    <message>
        <source>Due to widespread security flaws in BIP70 it's strongly recommended that any merchant instructions to switch wallets be ignored.</source>
        <translation>BIP70 ലെ വ്യാപകമായ സുരക്ഷാ പോരായ്മകൾ കാരണം, വാലറ്റുകൾ സ്വിച്ചുചെയ്യാനുള്ള ഏതെങ്കിലും വ്യാപാര നിർദ്ദേശങ്ങൾ അവഗണിക്കണമെന്ന് ശക്തമായി ശുപാർശ ചെയ്യുന്നു.</translation>
    </message>
    <message>
        <source>If you are receiving this error you should request the merchant provide a BIP21 compatible URI.</source>
        <translation>നിങ്ങൾക്ക് ഈ പിശക് ലഭിക്കുകയാണെങ്കിൽ, വ്യാപാരിയോട് ഒരു BIP21 അനുയോജ്യമായ URI നൽകാൻ അഭ്യർത്ഥിക്കണം.</translation>
    </message>
    <message>
        <source>Invalid payment address %1</source>
        <translation>പേയ്‌മെന്റ് വിലാസം അസാധുവാണ് %1</translation>
    </message>
    <message>
        <source>URI cannot be parsed! This can be caused by an invalid Bitcoin address or malformed URI parameters.</source>
        <translation>യു‌ആർ‌ഐ പാഴ്‌സുചെയ്യാൻ‌ കഴിയില്ല! അസാധുവായ ബിറ്റ്കോയിൻ വിലാസം അല്ലെങ്കിൽ കേടായ യു‌ആർ‌ഐ പാരാമീറ്ററുകൾ കാരണം ഇത് സംഭവിക്കാം.</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation>പേയ്‌മെന്റ് അഭ്യർത്ഥന ഫയൽ കൈകാര്യം ചെയ്യൽ</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>ഉപയോക്തൃ ഏജൻറ്</translation>
    </message>
    <message>
        <source>Node/Service</source>
        <translation>നോഡ് /സേവനങ്ങൾ </translation>
    </message>
    <message>
        <source>NodeId</source>
        <translation>നോഡ്ഐഡി</translation>
    </message>
    <message>
        <source>Ping</source>
        <translation>പിംഗ് </translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>അയക്കുക </translation>
    </message>
    <message>
        <source>Received</source>
        <translation>ലഭിച്ചവ </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>തുക </translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>ഒരു ബിറ്റ്കോയിൻ വിലാസം നൽകുക(e.g. %1)</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>തെറ്റ് : %1 </translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Received</source>
        <translation>ലഭിച്ചവ </translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>അയക്കുക </translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>ഉപയോക്തൃ ഏജൻറ്</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>നോഡ് വിൻഡോ</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>അവസാന ബ്ലോക്കിന്റെ സമയം </translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy label</source>
        <translation>പകർത്തുക  ലേബൽ</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>തുക പകർത്തുക</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>വാലറ്റ് അൺലോക്കുചെയ്യാനായില്ല.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>തുക:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>വാലറ്റ്:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>തീയതി </translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>നിര്‍ദ്ധിഷ്‌ടസംഖ്യ / അളവ് :</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ബൈറ്റ്സ്:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>തുക:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ഫീസ്‌ / പ്രതിഫലം :</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ഫീസ് കഴിഞ്ഞ്:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>മാറ്റം</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>പൊടി:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>നിര്‍ദ്ധിഷ്‌ടസംഖ്യ / അളവ് പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>തുക പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>പകർത്തു ഫീസ്</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>ശേഷമുള്ള ഫീ പകർത്തു</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>ബൈറ്റ്സ് പകർത്തു</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>ഡസ്ട് പകർത്തു</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>ചേഞ്ച് പകർത്തു</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>പെയ്മെന്റിനുള്ള അഭ്യർത്ഥന  കാലഹരണപ്പെട്ടു പോയിരിക്കുന്നു. </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Choose previously used address</source>
        <translation>മുൻപ്‌ ഉപയോഗിച്ച അഡ്രസ് തെരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>The Bitcoin address to send the payment to</source>
        <translation>പേയ്മെന്റ് അയക്കേണ്ട ബിറ്കോയിൻ അഡ്രസ് </translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Choose previously used address</source>
        <translation>മുൻപ്‌ ഉപയോഗിച്ച അഡ്രസ് തെരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>തീയതി </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>തുക </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>തീയതി </translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>വിലാസം പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>പകർത്തുക  ലേബൽ</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>തുക പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>ഇടപാട് ഐഡി പകർത്തുക</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>സ്ഥിതീകരിച്ചു</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>തീയതി </translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>വാലറ്റ് പൂട്ടുക </translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation>എല്ലാ വാലറ്റുകളും അടയ്‌ക്കുക ...</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>ഒരു പുതിയ വാലറ്റ് സൃഷ്ടിക്കുക</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>സ്ഥിരം ആയ വാലറ്റ്</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>പിശക് </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error reading from database, shutting down.</source>
        <translation>ഡാറ്റാബേസിൽ നിന്നും വായിച്ചെടുക്കുന്നതിനു തടസം നേരിട്ടു, പ്രവർത്തനം അവസാനിപ്പിക്കുന്നു.</translation>
    </message>
    <message>
        <source>Error upgrading chainstate database</source>
        <translation>ചെയിൻസ്റ്റേറ്റ് ഡാറ്റാബേസ് അപ്ഗ്രേഡ് ചെയ്യുന്നതിൽ തടസം നേരിട്ടു</translation>
    </message>
    <message>
        <source>Error: Disk space is low for %s</source>
        <translation>Error: %s ൽ ഡിസ്ക് സ്പേസ് വളരെ കുറവാണ്</translation>
    </message>
    <message>
        <source>Invalid -onion address or hostname: '%s'</source>
        <translation>തെറ്റായ ഒണിയൻ അഡ്രസ് അല്ലെങ്കിൽ ഹോസ്റ്റ്നെയിം: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address or hostname: '%s'</source>
        <translation>തെറ്റായ -പ്രോക്സി അഡ്രസ് അല്ലെങ്കിൽ ഹോസ്റ്റ് നെയിം : '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s' (must be at least %s)</source>
        <translation>തെറ്റായ തുക  -paytxfee=&lt;amount&gt; :'%s' (ഏറ്റവും കുറഞ്ഞത് %s എങ്കിലും ആയിരിക്കണം )</translation>
    </message>
    <message>
        <source>Invalid netmask specified in -whitelist: '%s'</source>
        <translation>-whitelist: '%s' ൽ രേഖപ്പെടുത്തിയിരിക്കുന്ന netmask തെറ്റാണ് </translation>
    </message>
    <message>
        <source>Need to specify a port with -whitebind: '%s'</source>
        <translation>-whitebind: '%s' നൊടൊപ്പം ഒരു പോർട്ട് കൂടി നിർദ്ദേശിക്കേണ്ടതുണ്ട് </translation>
    </message>
    <message>
        <source>Prune mode is incompatible with -blockfilterindex.</source>
        <translation>-blockfilterindex നൊടൊപ്പം പൃണ് മോഡ് സാധ്യമല്ല .</translation>
    </message>
    <message>
        <source>Reducing -maxconnections from %d to %d, because of system limitations.</source>
        <translation>സിസ്റ്റത്തിന്റെ പരിമിധികളാൽ -maxconnections ന്റെ മൂല്യം %d ൽ  നിന്നും %d യിലേക്ക് കുറക്കുന്നു.</translation>
    </message>
    <message>
        <source>Section [%s] is not recognized.</source>
        <translation>Section [%s]  തിരിച്ചറിഞ്ഞില്ല.</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>ഇടപാട് സൈൻ ചെയ്യുന്നത് പരാജയപ്പെട്ടു.</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" does not exist</source>
        <translation>നിർദേശിച്ച -walletdir "%s" നിലവിൽ ഇല്ല</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is a relative path</source>
        <translation>നിർദേശിച്ച -walletdir "%s" ഒരു റിലേറ്റീവ് പാത്ത് ആണ്</translation>
    </message>
    <message>
        <source>Specified -walletdir "%s" is not a directory</source>
        <translation>നിർദേശിച്ച  -walletdir "%s" ഒരു ഡയറക്ടറി അല്ല </translation>
    </message>
    <message>
        <source>The specified config file %s does not exist
</source>
        <translation>നിർദേശിച്ച കോൺഫിഗുറേഷൻ ഫയൽ  %s നിലവിലില്ല 
</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation>ഇടപാട് മൂല്യം തീരെ കുറവായതിനാൽ പ്രതിഫലം നൽകാൻ കഴിയില്ല.</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>ഇത് പരീക്ഷിച്ചുകൊണ്ടിരിക്കുന്ന ഒരു സോഫ്റ്റ്‌വെയർ ആണ്.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>ഇടപാട് മൂല്യം വളരെ കുറവാണ്</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>ഇടപാട് വളരെ വലുതാണ് </translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %s)</source>
        <translation>ഈ കംപ്യൂട്ടറിലെ %s ൽ ബൈൻഡ് ചെയ്യാൻ സാധിക്കുന്നില്ല ( ബൈൻഡ് തിരികെ തന്ന പിശക് %s )</translation>
    </message>
    <message>
        <source>Unable to create the PID file '%s': %s</source>
        <translation>PID ഫയൽ '%s': %s നിർമിക്കാൻ സാധിക്കുന്നില്ല </translation>
    </message>
    <message>
        <source>Unable to generate initial keys</source>
        <translation>പ്രാഥമിക കീ നിർമ്മിക്കാൻ സാധിക്കുന്നില്ല</translation>
    </message>
    <message>
        <source>Unknown -blockfilterindex value %s.</source>
        <translation>-blockfilterindex ന്റെ മൂല്യം %s മനസിലാക്കാൻ കഴിയുന്നില്ല.</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>വാലറ്റ്(കൾ) പരിശോധിക്കുന്നു...</translation>
    </message>
    <message>
        <source>Warning: unknown new rules activated (versionbit %i)</source>
        <translation>മുന്നറിയിപ്പ്: പുതിയ ഒരു നിയമം ആക്ടിവേറ്റ് ചെയ്തിരിക്കുന്നു (versionbit %i)</translation>
    </message>
    <message>
        <source>-maxtxfee is set very high! Fees this large could be paid on a single transaction.</source>
        <translation>-maxtxfee യുടെ മൂല്യം വളരെ വലുതാണ്! ഇത്രയും ഉയര്ന്ന പ്രതിഫലം ഒരൊറ്റ ഇടപാടിൽ നൽകാൻ സാധ്യതയുണ്ട്.</translation>
    </message>
    <message>
        <source>This is the transaction fee you may pay when fee estimates are not available.</source>
        <translation>പ്രതിഫലം മൂല്യനിർണയം ലഭ്യമാകാത്ത പക്ഷം നിങ്ങൾ നല്കേണ്ടിവരുന്ന ഇടപാട് പ്രതിഫലം ഇതാണ്.</translation>
    </message>
    </context>
</TS>